"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigManagerMessageHandler = void 0;
const config_1 = require("@zwave-js/config");
const error_1 = require("../error");
const command_1 = require("./command");
class ConfigManagerMessageHandler {
    configManager = new config_1.ConfigManager();
    constructor() {
        this.configManager.loadDeviceIndex().then(() => { });
    }
    async handle(message) {
        const { command } = message;
        switch (message.command) {
            case command_1.ConfigManagerCommand.lookupDevice: {
                const config = await this.configManager.lookupDevice(message.manufacturerId, message.productType, message.productId, message.firmwareVersion);
                return { config };
            }
            case command_1.ConfigManagerCommand.loadManufacturers: {
                await this.configManager.loadManufacturers();
                return {};
            }
            case command_1.ConfigManagerCommand.lookupManufacturer: {
                const name = this.configManager.lookupManufacturer(message.manufacturerId);
                return { name };
            }
            case command_1.ConfigManagerCommand.loadDeviceIndex: {
                await this.configManager.loadDeviceIndex();
                return {};
            }
            case command_1.ConfigManagerCommand.getIndex: {
                const index = this.configManager.getIndex();
                return { index };
            }
            case command_1.ConfigManagerCommand.loadFulltextDeviceIndex: {
                await this.configManager.loadFulltextDeviceIndex();
                return {};
            }
            case command_1.ConfigManagerCommand.getFulltextIndex: {
                const index = this.configManager.getFulltextIndex();
                return { index };
            }
            case command_1.ConfigManagerCommand.lookupDevicePreserveConditions: {
                const config = await this.configManager.lookupDevicePreserveConditions(message.manufacturerId, message.productType, message.productId, message.firmwareVersion);
                return { config };
            }
            case command_1.ConfigManagerCommand.manufacturers: {
                const manufacturers = this.configManager.manufacturers;
                return { manufacturers };
            }
            case command_1.ConfigManagerCommand.loadAll: {
                await this.configManager.loadAll();
                return {};
            }
            case command_1.ConfigManagerCommand.configVersion: {
                return { configVersion: this.configManager.configVersion };
            }
            default: {
                throw new error_1.UnknownCommandError(command);
            }
        }
    }
}
exports.ConfigManagerMessageHandler = ConfigManagerMessageHandler;
