"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UtilsMessageHandler = void 0;
const zwave_js_1 = require("zwave-js");
const core_1 = require("@zwave-js/core");
const error_1 = require("../error");
const command_1 = require("./command");
class UtilsMessageHandler {
    async handle(message) {
        const { command } = message;
        switch (message.command) {
            case command_1.UtilsCommand.parseQRCodeString: {
                const qrProvisioningInformation = (0, core_1.parseQRCodeString)(message.qr);
                return { qrProvisioningInformation };
            }
            case command_1.UtilsCommand.tryParseDSKFromQRCodeString: {
                const dsk = (0, core_1.tryParseDSKFromQRCodeString)(message.qr);
                return { dsk };
            }
            case command_1.UtilsCommand.num2hex: {
                const hex = (0, zwave_js_1.num2hex)(message.val, message.uppercase);
                return { hex };
            }
            case command_1.UtilsCommand.formatId: {
                const id = (0, zwave_js_1.formatId)(message.id);
                return { id };
            }
            case command_1.UtilsCommand.buffer2hex: {
                const hex = (0, zwave_js_1.buffer2hex)(message.buffer, message.uppercase);
                return { hex };
            }
            case command_1.UtilsCommand.getEnumMemberName: {
                const name = (0, zwave_js_1.getEnumMemberName)(message.enumeration, message.value);
                return { name };
            }
            case command_1.UtilsCommand.rssiToString: {
                const rssi = (0, zwave_js_1.rssiToString)(message.rssi);
                return { rssi };
            }
            default: {
                throw new error_1.UnknownCommandError(command);
            }
        }
    }
}
exports.UtilsMessageHandler = UtilsMessageHandler;
